@@ -7,6 +7,7 @@ BEGIN
 {
 use strict;
 use vars qw($VERSION @EXPORT_OK %TigrignaEquivalence %TigrignaClassEquivalence);
+# require Regexp::Ethiopic;
 
 
 	$VERSION = "0.05";
@@ -131,7 +132,6 @@ $TigrignaClassEquivalence{'ፀ'}
 	;
 }
 
-
 sub import
 {
 
@@ -155,30 +155,6 @@ sub import
 }
 
 
-#
-# move into Regexp::Ethiopic later...
-#
-sub getFamilyEquivalent
-{
-my ($chars) = @_;
-
-
-	return $chars if ( length($chars) == 1 );
-
-	$chars =~ s/(\w)(?=\w)/$1,/og;
-	my @Chars = split ( /,/, $chars );
-	my $return;
-	foreach (@Chars) {
-		$char = $_;
-		foreach	( keys %TigrignaClassEquivalence ) {
-			$return .= $_ if ( $TigrignaClassEquivalence{$char} eq $TigrignaClassEquivalence{$_} );
-		}
-	}
-
-	$return;
-}
-
-
 sub getRe
 {
 $_ = ($#_) ? $_[1] : $_[0];
@@ -186,7 +162,6 @@ $_ = ($#_) ? $_[1] : $_[0];
 
 	s/\[=(\p{Ethiopic})=\]/($TigrignaEquivalence{$1}) ? "[$TigrignaEquivalence{$1}]" : $1/eog;
 	s/\[=#(\p{Ethiopic})#=\]/($TigrignaClassEquivalence{$1}) ? "[$TigrignaClassEquivalence{$1}]" : $1/eog;
-	s/\[=#([\p{Ethiopic}]+)#=\]/Regexp::Ethiopic::setRange(getFamilyEquivalent($1),"all")/eog;
 
 	Regexp::Ethiopic::getRe ( $_ );
 }
@@ -202,7 +177,6 @@ $_ = ($#_) ? $_[1] : $_[0];
 
 __END__
 
-=encoding utf8
 
 =head1 NAME
 
